# SEC09-BP03: Authenticate network communications

## Description

mTLS.

## Implementation Guidance

- Mutual TLS for service-to-service
- Certificate-based authentication
- Service mesh for mTLS
- API authentication
- Zero trust network access

## Risk Level

Medium - Unauthenticated connections are spoofable.
